/*
 * SPDX-License-Identifier: GPL-2.0+
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2, or (at
 * your option) any later version.
 *
 * You can also choose to distribute this program under the terms of
 * the Unmodified Binary Distribution Licence (as given in the file
 * COPYING.UBDL), provided that you have satisfied its requirements.
 */
#ifndef _GPXE_ARP_H
#define _GPXE_ARP_H

/** @file
 *
 * Address Resolution Protocol
 *
 */

FILE_LICENCE ( GPL2_OR_LATER_OR_UBDL );

#include <gpxe/tables.h>

struct net_device;
struct net_protocol;
struct ll_protocol;

/** A network-layer protocol that relies upon ARP */
struct arp_net_protocol {
	/** Network-layer protocol */
	struct net_protocol *net_protocol;
	/** Check existence of address
	 *
	 * @v netdev	Network device
	 * @v net_addr	Network-layer address
	 * @ret rc	Return status code
	 */
	int ( * check ) ( struct net_device *netdev,
			  const void *net_addr );
};

/** ARP protocol table */
#define ARP_NET_PROTOCOLS \
	__table ( struct arp_net_protocol, "arp_net_protocols" )

/** Declare an ARP protocol */
#define __arp_net_protocol __table_entry ( ARP_NET_PROTOCOLS, 01 )

extern struct net_protocol arp_protocol;

void arp_add_entry ( struct ll_protocol *ll_protocol,
		     struct net_protocol *net_protocol,
		     const void *ll_addr, const void *net_addr,
		     int fixed );

void arp_update_entry ( struct ll_protocol *ll_protocol,
			struct net_protocol *net_protocol,
			const void *ll_addr, const void *net_addr);

void arp_reserve_entry ( struct ll_protocol *ll_protocol,
			 struct net_protocol *net_protocol,
			 const void *net_addr );

extern int arp_resolve ( struct net_device *netdev,
			 struct net_protocol *net_protocol,
			 const void *dest_net_addr,
			 const void *source_net_addr,
			 void *dest_ll_addr );

extern void arp_reset ( void );

#endif /* _GPXE_ARP_H */
