/*
 * SPDX-License-Identifier: GPL-2.0+
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2, or (at
 * your option) any later version.
 *
 * You can also choose to distribute this program under the terms of
 * the Unmodified Binary Distribution Licence (as given in the file
 * COPYING.UBDL), provided that you have satisfied its requirements.
 */
#ifndef _GPXE_DHCPOPTS_H
#define _GPXE_DHCPOPTS_H

/** @file
 *
 * DHCP options
 *
 */

FILE_LICENCE ( GPL2_OR_LATER_OR_UBDL );

#include <stdint.h>

/** A DHCP options block */
struct dhcp_options {
	/** Option block raw data */
	void *data;
	/** Option block used length */
	size_t used_len;
	/** Option block allocated length */
	size_t alloc_len;
	/** Reallocate option block raw data
	 *
	 * @v options		DHCP option block
	 * @v len		New length
	 * @ret rc		Return status code
	 */
	int ( * realloc ) ( struct dhcp_options *options, size_t len );
};

extern int dhcpopt_applies ( unsigned int tag );
extern int dhcpopt_store ( struct dhcp_options *options, unsigned int tag,
			   const void *data, size_t len );
extern int dhcpopt_extensible_store ( struct dhcp_options *options,
				      unsigned int tag, const void *data,
				      size_t len );
extern int dhcpopt_fetch ( struct dhcp_options *options, unsigned int tag,
			   void *data, size_t len );
extern void dhcpopt_init ( struct dhcp_options *options,
			   void *data, size_t alloc_len,
			   int ( * realloc ) ( struct dhcp_options *options,
					       size_t len ) );
extern void dhcpopt_update_used_len ( struct dhcp_options *options );
extern int dhcpopt_realloc ( struct dhcp_options *options, size_t len );
extern int dhcpopt_no_realloc ( struct dhcp_options *options, size_t len );

#endif /* _GPXE_DHCPOPTS_H */
