/*
 * SPDX-License-Identifier: GPL-2.0+
 *
 * Driver for Solarflare network controllers and boards
 * Copyright 2019 Solarflare Communications Inc.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 as published
 * by the Free Software Foundation, incorporated herein by reference.
 *
 * You can also choose to distribute this program under the terms of
 * the Unmodified Binary Distribution Licence (as given in the file
 * COPYING.UBDL), provided that you have satisfied its requirements.
 */
#ifndef _GPXE_SF_SETTINGS_H
#define _GPXE_SF_SETTINGS_H

FILE_LICENCE ( GPL2_OR_LATER_OR_UBDL );

/** @file
 *
 * Additional core settings for configuring Solarflare NICs
 *
 */

#include <stdarg.h>
#include <gpxe/settings.h>

struct net_device;
struct nvo_block;

/** Maximum delay values (for hangup protection) */
#define MAX_BANNER_DELAY	30
#define MAX_BOOTSKIP_DELAY	30
#define MAX_LINKUP_DELAY	255

#define BOOTTYPE_PXE		0
#define BOOTTYPE_ISCSI		1
#define BOOTTYPE_DISABLED	2
#define NUM_BOOTTYPES		3

#define BOOTIMAGE_PXE_UEFI	0
#define BOOTIMAGE_PXE		1
#define BOOTIMAGE_UEFI		2
#define BOOTIMAGE_NONE		3

/* Validation definitions */
#define SF_PASSWD_LEN_MIN		12
#define SF_PASSWD_LEN_MAX		20
#define SF_USERID_LEN_MAX		64
#define SF_VCI_LEN_MAX			8
#define SF_INITIATOR_LEN_MAX		223	/* rfc3720 */
#define SF_TARGET_SERVER_LEN_MAX	255	/* rfc2181 */
#define SF_TARGET_IQN_LEN_MAX		223	/* rfc3720 */

extern struct setting mpio_attempts_setting __setting;
extern struct setting banner_delay_setting __setting;
extern struct setting bootskip_delay_setting __setting;
extern struct setting linkup_delay_setting __setting;
extern struct setting lun_retries_setting __setting;
extern struct setting initiator_iqn_setting __setting;
extern struct setting reverse_username_setting __setting;
extern struct setting reverse_password_setting __setting;
extern struct setting dhcp_vendor_class_setting __setting;
extern struct setting boot_type_setting __setting;
extern struct setting mpio_priority_setting __setting;
extern struct setting chap_setting __setting;
extern struct setting chap_target_setting __setting;
extern struct setting initiator_dhcp_setting __setting;
extern struct setting target_dhcp_setting __setting;
extern struct setting initiator_iqn_dhcp_setting __setting;
extern struct setting boot_image_setting __setting;
extern struct setting target_name_setting __setting;
extern struct setting msix_limit_setting __setting;
extern struct setting port_setting __setting;
extern struct setting server_name_setting __setting;
extern struct setting sriov_setting __setting;
extern struct setting siena_vf_msix_limit_setting __setting;
extern struct setting hunt_vf_msix_limit_setting __setting;
extern struct setting vf_count_setting __setting;
extern struct setting lun_setting __setting;
extern struct setting firmware_variant_setting __setting;
extern struct setting pf_count_setting __setting;
extern struct setting pfiov_setting __setting;
extern struct setting vlan_tag_setting __setting;
extern struct setting vlan_setting __setting;
extern struct setting port_mode_setting __setting;
extern struct setting insecure_filters_setting __setting;

extern struct settings *sf_default_settings;

extern long sf_sett_get_intz(struct settings *settings,
			     struct setting *setting);

extern int sf_sett_fetcha_string(struct settings *settingss,
				 struct setting *setting,
				 char **value);
extern int sf_sett_fetch_string(struct settings *settings,
                                struct setting *setting,
                                char *buf, size_t sz);
extern int sf_root_path_fetch(struct net_device *dev, char *buf, size_t sz);

#define PRIORITY_KEY_NONE -1ULL

/* Produce a sortable key for the mpio priority of a net_device. Suitable for
 * producing an ordered list of devices. 0 = highest
 *
 * A return value of %PRIORITY_KEY_NONE means this device is not selected
 * for iSCSI boot.
 */
extern uint64_t sf_mpio_priority_key(struct net_device* net_dev) __pure;

#endif /* _GPXE_SF_SETTINGS_H */
